@@ -78,11 +78,11 @@ void TestWaylandOutputDevice::init()
     using namespace KWaylandServer;
     delete m_display;
     m_display = new Display(this);
-    m_display->setSocketName(s_socketName);
+    m_display->addSocketName(s_socketName);
     m_display->start();
     QVERIFY(m_display->isRunning());
 
-    m_serverOutputDevice = m_display->createOutputDevice(this);
+    m_serverOutputDevice = new OutputDeviceInterface(m_display, this);
     m_serverOutputDevice->setUuid("1337");
 
 
