@@ -89,23 +89,23 @@ void XdgShellTest::init()
 {
     delete m_display;
     m_display = new Display(this);
-    m_display->setSocketName(s_socketName);
+    m_display->addSocketName(s_socketName);
     m_display->start();
     QVERIFY(m_display->isRunning());
     m_display->createShm();
-    m_o1Interface = m_display->createOutput(m_display);
+    m_o1Interface = new OutputInterface(m_display, m_display);
     m_o1Interface->addMode(QSize(1024, 768));
     m_o1Interface->create();
-    m_o2Interface = m_display->createOutput(m_display);
+    m_o2Interface = new OutputInterface(m_display, m_display);
     m_o2Interface->addMode(QSize(1024, 768));
     m_o2Interface->create();
-    m_seatInterface = m_display->createSeat(m_display);
+    m_seatInterface = new SeatInterface(m_display, m_display);
     m_seatInterface->setHasKeyboard(true);
     m_seatInterface->setHasPointer(true);
     m_seatInterface->setHasTouch(true);
     m_seatInterface->create();
-    m_compositorInterface = m_display->createCompositor(m_display);
-    m_xdgShellInterface = m_display->createXdgShell(m_display);
+    m_compositorInterface = new CompositorInterface(m_display, m_display);
+    m_xdgShellInterface = new XdgShellInterface(m_display, m_display);
 
     // setup connection
     m_connection = new KWayland::Client::ConnectionThread;
@@ -189,13 +189,15 @@ void XdgShellTest::cleanup()
         m_thread = nullptr;
     }
 
-    CLEANUP(m_compositorInterface)
-    CLEANUP(m_xdgShellInterface)
-    CLEANUP(m_o1Interface);
-    CLEANUP(m_o2Interface);
-    CLEANUP(m_seatInterface);
     CLEANUP(m_display)
 #undef CLEANUP
+
+    // these are the children of the display
+    m_compositorInterface = nullptr;
+    m_xdgShellInterface = nullptr;
+    m_o1Interface = nullptr;
+    m_o2Interface = nullptr;
+    m_seatInterface = nullptr;
 }
 
 void XdgShellTest::testCreateSurface()
