@@ -8,12 +8,18 @@
 
 #include "global.h"
 
-struct wl_client;
-struct wl_interface;
+#include <QPointer>
+
+#include <wayland-server-core.h>
 
 namespace KWaylandServer
 {
 
+struct DisplayDestroyListener : public wl_listener
+{
+    Global *global = nullptr;
+};
+
 class Global::Private
 {
 public:
@@ -21,8 +27,12 @@ public:
     virtual ~Private();
     void create();
 
-    Display *display = nullptr;
+    // We need to reset display from the destroy listener, but due to the private class
+    // being nested, this is not easy to do so. Either way, we are moving away from the
+    // old approach, so it's not worth wasting our time.
+    QPointer<Display> display;
     wl_global *global = nullptr;
+    DisplayDestroyListener displayDestroyListener;
 
 protected:
     Private(Display *d, const wl_interface *interface, quint32 version);
