@@ -23,7 +23,8 @@ class AbstractDataSource;
 class DataDeviceInterface;
 class DataSourceInterface;
 class DataControlDeviceV1Interface;
-class TextInputInterface;
+class TextInputV2Interface;
+class TextInputV3Interface;
 class PrimarySelectionDeviceV1Interface;
 
 class SeatInterface::Private : public Global::Private
@@ -37,27 +38,31 @@ public:
     QVector<KeyboardInterface *> keyboardsForSurface(SurfaceInterface *surface) const;
     QVector<TouchInterface *> touchsForSurface(SurfaceInterface *surface) const;
     QVector<DataDeviceInterface *> dataDevicesForSurface(SurfaceInterface *surface) const;
-    TextInputInterface *textInputForSurface(SurfaceInterface *surface) const;
     void registerPrimarySelectionDevice(PrimarySelectionDeviceV1Interface *primarySelectionDevice);
     void registerDataDevice(DataDeviceInterface *dataDevice);
     void registerDataControlDevice(DataControlDeviceV1Interface *dataDevice);
-    void registerTextInput(TextInputInterface *textInput);
     void endDrag(quint32 serial);
+    void cancelDrag(quint32 serial);
+    quint32 nextSerial() const;
 
     QString name;
     bool pointer = false;
-    bool keyboard = false;
     bool touch = false;
     QList<wl_resource*> resources;
     quint32 timestamp = 0;
     QVector<PointerInterface*> pointers;
-    QVector<KeyboardInterface*> keyboards;
+    QScopedPointer<KeyboardInterface> keyboard;
     QVector<TouchInterface*> touchs;
     QVector<DataDeviceInterface*> dataDevices;
     QVector<PrimarySelectionDeviceV1Interface*> primarySelectionDevices;
     QVector<DataControlDeviceV1Interface*> dataControlDevices;
 
-    QVector<TextInputInterface*> textInputs;
+    // TextInput v2
+    QPointer<TextInputV2Interface> textInputV2;
+    QPointer<TextInputV3Interface> textInputV3;
+
+    SurfaceInterface *focusedTextInputSurface = nullptr;
+    QMetaObject::Connection focusedSurfaceDestroyConnection;
 
     // the last thing copied into the clipboard content
     AbstractDataSource *currentSelection = nullptr;
@@ -89,52 +94,16 @@ public:
 
     // Keyboard related members
     struct Keyboard {
-        enum class State {
-            Released,
-            Pressed
-        };
-        QHash<quint32, State> states;
-        struct Keymap {
-            bool xkbcommonCompatible = false;
-            QByteArray content;
-        };
-        Keymap keymap;
-        struct Modifiers {
-            quint32 depressed = 0;
-            quint32 latched = 0;
-            quint32 locked = 0;
-            quint32 group = 0;
-            quint32 serial = 0;
-        };
-        Modifiers modifiers;
         struct Focus {
             SurfaceInterface *surface = nullptr;
-            QVector<KeyboardInterface*> keyboards;
             QMetaObject::Connection destroyConnection;
             quint32 serial = 0;
             QVector<DataDeviceInterface *> selections;
             QVector<PrimarySelectionDeviceV1Interface *> primarySelections;
         };
         Focus focus;
-        quint32 lastStateSerial = 0;
-        struct {
-            qint32 charactersPerSecond = 0;
-            qint32 delay = 0;
-        } keyRepeat;
     };
-    Keyboard keys;
-    bool updateKey(quint32 key, Keyboard::State state);
-
-    struct TextInput {
-        struct Focus {
-            SurfaceInterface *surface = nullptr;
-            QMetaObject::Connection destroyConnection;
-            quint32 serial = 0;
-            TextInputInterface *textInput = nullptr;
-        };
-        Focus focus;
-    };
-    TextInput textInput;
+    Keyboard globalKeyboard;
 
     // Touch related members
     struct Touch {
@@ -158,7 +127,7 @@ public:
         };
         Mode mode = Mode::None;
         DataDeviceInterface *source = nullptr;
-        DataDeviceInterface *target = nullptr;
+        QPointer<DataDeviceInterface> target;
         SurfaceInterface *surface = nullptr;
         PointerInterface *sourcePointer = nullptr;
         TouchInterface *sourceTouch = nullptr;
